summaryrefslogtreecommitdiff
path: root/source3/passdb/passdb.c
diff options
context:
space:
mode:
Diffstat (limited to 'source3/passdb/passdb.c')
-rw-r--r--source3/passdb/passdb.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/passdb/passdb.c b/source3/passdb/passdb.c
index d262b09520..f34513b225 100644
--- a/source3/passdb/passdb.c
+++ b/source3/passdb/passdb.c
@@ -183,7 +183,7 @@ NTSTATUS pdb_fill_sam_pw(SAM_ACCOUNT *sam_account, const struct passwd *pwd)
mechinism, we should call it here.
We can't just set this to 0 or allow it only to be filled
- in when added to the backend, becouse the user's SID
+ in when added to the backend, because the user's SID
may already be in security descriptors etc.
-- abartlet 11-May-02
@@ -629,7 +629,7 @@ uint32 pdb_gid_to_group_rid(gid_t gid)
static BOOL pdb_rid_is_well_known(uint32 rid)
{
/* Not using rid_offset here, becouse this is the actual
NT fixed value (1000) */
return (rid < BASE_RID);
@@ -629,7 +629,7 @@ uint32 pdb_gid_to_group_rid(gid_t gid)
static BOOL pdb_rid_is_well_known(uint32 rid)
{
- /* Not using rid_offset here, becouse this is the actual
+ /* Not using rid_offset here, because this is the actual
NT fixed value (1000) */
return (rid < BASE_RID);